import type { AxiosResponse } from 'axios'
import type { ResponseInfo } from '@/types/axios'

import { ElMessage } from 'element-plus'
import { MessageType } from '@/types/axios'

import 'element-plus/theme-chalk/el-message.css'
import 'element-plus/theme-chalk/el-message-box.css'

export function useRequest() {
  let baseURL = ''
  if (import.meta.env.MODE === 'development') {
    baseURL = 'http://server.ichunhao.cn'
  } else {
    baseURL = 'http://service.ichunhao.cn'
  }

  const AllApi = {
    userLogin: ``,
    mockAdTTAcc: `http://127.0.0.1:8003/mock/ad/ttacc`,
    mockAdTTProj: `http://127.0.0.1:8003/mock/ad/ttproj`,
    mockAdTTAd: `http://127.0.0.1:8003/mock/ad/ttad`,
    mockChart: `http://127.0.0.1:8003/mock/home/chart`,
    mockChartProduct: `http://127.0.0.1:8003/mock/home/chartProduct`,
    mockOverview: `http://127.0.0.1:8003/mock/home/overview`,
    getRefreshToken: '',
  }

  /**
   * @description: 根据返回码给出提示
   * @param {AxiosResponse} data 返回的数据
   * @param {string} kind 请求类型
   * @return {*}
   */
  const analysisResCode = (
    data: AxiosResponse,
    kind = '请求',
    showMsg = true,
  ): Promise<ResponseInfo> => {
    return new Promise((resolve, reject) => {
      let info = JSON.parse(JSON.stringify(data)) as ResponseInfo

      let type: MessageType = MessageType.Success
      let message = info.msg
      let kindText = kind === 'login' ? '登录' : '请求'
      switch (info.code) {
        case 0:
          {
            type = MessageType.Success
            message = `${kindText}成功`
            resolve(info)
          }
          break
        default: {
          type = MessageType.Error
          reject(info.msg)
        }
      }
      if (showMsg) {
        ElMessage({
          type,
          message,
          duration: 1000,
        })
      }
    })
  }

  return {
    AllApi,
    baseURL,
    analysisResCode,
  }
}
